DNA Weaver
===========

DNA Weaver is a Python library to find optimal strategies for assembling large
DNA constructs. Given an arbitrary sequence, DNA Weaver will select the most
adapted commercial DNA providers, cloning methods and parts repositories
(depending on your preferences), and will design all necessary assembly fragments
and assembly steps.

DNA Weaver was written with versatility and extensibility in mind:
each DNA source and assembly method can be customized, and assembly plans can
be optimized with respect to total price, overall duration of the assembly,
or assembly success probabilities.

Infos
-----

**PIP installation:**

.. code:: bash

  pip install dnaweaver

**Web documentation:**

`<https://edinburgh-genome-foundry.github.io/DnaWeaver/>`_

**Github Page**

`<https://github.com/Edinburgh-Genome-Foundry/Dnaweaver>`_

**Live demo**

`<https://dnaweaver.genomefoundry.org>`_

**License:** MIT, Copyright Edinburgh Genome Foundry

More biology software
---------------------

.. image:: https://raw.githubusercontent.com/Edinburgh-Genome-Foundry/Edinburgh-Genome-Foundry.github.io/master/static/imgs/logos/egf-codon-horizontal.png
  :target: https://edinburgh-genome-foundry.github.io/

DNA Weaver is part of the `EGF Codons <https://edinburgh-genome-foundry.github.io/>`_ synthetic biology software suite for DNA design, manufacturing and validation.
